pub struct ByteBoolEncoding;Trait Implementations
Sourceimpl ComputeVTable for ByteBoolEncoding
impl ComputeVTable for ByteBoolEncoding
Sourcefn scalar_at_fn(&self) -> Option<&dyn ScalarAtFn<&dyn Array>>
fn scalar_at_fn(&self) -> Option<&dyn ScalarAtFn<&dyn Array>>
Single item indexing on Vortex arrays. Read more
Sourcefn slice_fn(&self) -> Option<&dyn SliceFn<&dyn Array>>
fn slice_fn(&self) -> Option<&dyn SliceFn<&dyn Array>>
Perform zero-copy slicing of an array. Read more
Sourcefn take_fn(&self) -> Option<&dyn TakeFn<&dyn Array>>
fn take_fn(&self) -> Option<&dyn TakeFn<&dyn Array>>
Take a set of indices from an array. This often forces allocations and decoding of
the receiver. Read more
Sourcefn fill_null_fn(&self) -> Option<&dyn FillNullFn<&dyn Array>>
fn fill_null_fn(&self) -> Option<&dyn FillNullFn<&dyn Array>>
Fill null values with given desired value. Resulting array is NonNullable Read more
Sourcefn is_constant_fn(&self) -> Option<&dyn IsConstantFn<&dyn Array>>
fn is_constant_fn(&self) -> Option<&dyn IsConstantFn<&dyn Array>>
Checks if an array is constant. Read more
fn is_sorted_fn(&self) -> Option<&dyn IsSortedFn<&dyn Array>>
Sourcefn like_fn(&self) -> Option<&dyn LikeFn<&dyn Array>>
fn like_fn(&self) -> Option<&dyn LikeFn<&dyn Array>>
Perform a SQL LIKE operation on two arrays. Read more
Sourcefn min_max_fn(&self) -> Option<&dyn MinMaxFn<&dyn Array>>
fn min_max_fn(&self) -> Option<&dyn MinMaxFn<&dyn Array>>
Compute the min, max of an array. Read more
Sourcefn optimize_fn(&self) -> Option<&dyn OptimizeFn<&dyn Array>>
fn optimize_fn(&self) -> Option<&dyn OptimizeFn<&dyn Array>>
Try and optimize the layout of an array. Read more
Sourcefn search_sorted_fn(&self) -> Option<&dyn SearchSortedFn<&dyn Array>>
fn search_sorted_fn(&self) -> Option<&dyn SearchSortedFn<&dyn Array>>
Perform a search over an ordered array. Read more
Sourcefn search_sorted_usize_fn(&self) -> Option<&dyn SearchSortedUsizeFn<&dyn Array>>
fn search_sorted_usize_fn(&self) -> Option<&dyn SearchSortedUsizeFn<&dyn Array>>
Perform a search over an ordered array. Read more
fn take_from_fn(&self) -> Option<&dyn TakeFromFn<&dyn Array>>
Sourcefn to_arrow_fn(&self) -> Option<&dyn ToArrowFn<&dyn Array>>
fn to_arrow_fn(&self) -> Option<&dyn ToArrowFn<&dyn Array>>
Convert the array to an Arrow array of the given type. Read more
Sourcefn uncompressed_size_fn(&self) -> Option<&dyn UncompressedSizeFn<&dyn Array>>
fn uncompressed_size_fn(&self) -> Option<&dyn UncompressedSizeFn<&dyn Array>>
Approximates the uncompressed size of the array. Read more
Sourceimpl Debug for ByteBoolEncoding
impl Debug for ByteBoolEncoding
Sourceimpl Encoding for ByteBoolEncoding
impl Encoding for ByteBoolEncoding
type Array = ByteBoolArray
type Metadata = EmptyMetadata
fn vtable(&'static self) -> ArcRef<dyn EncodingVTable>where
Self: Sized,
Sourceimpl EncodingVTable for ByteBoolEncoding
impl EncodingVTable for ByteBoolEncoding
Sourcefn id(&self) -> EncodingId
fn id(&self) -> EncodingId
Return the ID for this encoding implementation.
fn decode( &self, parts: &ArrayParts, ctx: &ArrayContext, dtype: DType, len: usize, ) -> VortexResult<ArrayRef>
Sourceimpl MaskKernel for ByteBoolEncoding
impl MaskKernel for ByteBoolEncoding
Sourcefn mask(&self, array: &ByteBoolArray, mask: &Mask) -> VortexResult<ArrayRef>
fn mask(&self, array: &ByteBoolArray, mask: &Mask) -> VortexResult<ArrayRef>
Replace masked values with null in array.
Sourceimpl ScalarAtFn<&ByteBoolArray> for ByteBoolEncoding
impl ScalarAtFn<&ByteBoolArray> for ByteBoolEncoding
fn scalar_at(&self, array: &ByteBoolArray, index: usize) -> VortexResult<Scalar>
Sourceimpl SliceFn<&ByteBoolArray> for ByteBoolEncoding
impl SliceFn<&ByteBoolArray> for ByteBoolEncoding
Sourcefn slice(
&self,
array: &ByteBoolArray,
start: usize,
stop: usize,
) -> VortexResult<ArrayRef>
fn slice( &self, array: &ByteBoolArray, start: usize, stop: usize, ) -> VortexResult<ArrayRef>
Return a zero-copy slice of an array, between
start (inclusive) and end (exclusive).
If start >= stop, returns an empty array of the same type as self.
Assumes that start or stop are out of bounds, may panic otherwise.Sourceimpl TakeFn<&ByteBoolArray> for ByteBoolEncoding
impl TakeFn<&ByteBoolArray> for ByteBoolEncoding
Sourcefn take(
&self,
array: &ByteBoolArray,
indices: &dyn Array,
) -> VortexResult<ArrayRef>
fn take( &self, array: &ByteBoolArray, indices: &dyn Array, ) -> VortexResult<ArrayRef>
Sourcefn take_into(
&self,
array: A,
indices: &dyn Array,
builder: &mut dyn ArrayBuilder,
) -> Result<(), VortexError>
fn take_into( &self, array: A, indices: &dyn Array, builder: &mut dyn ArrayBuilder, ) -> Result<(), VortexError>
Has the same semantics as
Self::take but materializes the result into the provided
builder.Auto Trait Implementations
impl Freeze for ByteBoolEncoding
impl RefUnwindSafe for ByteBoolEncoding
impl Send for ByteBoolEncoding
impl Sync for ByteBoolEncoding
impl Unpin for ByteBoolEncoding
impl UnwindSafe for ByteBoolEncoding